@@ -186,7 +186,7 @@ class binary_eda_plot:
         
     def plot_discrete(self, col, ax):
         
-        a = self.data[col].value_counts()
+        a = self.data[col].value_counts(sort=False)
         a.name = 'total'
         
         b = self.data[self.data[self.target]==1][col].value_counts()
@@ -225,7 +225,7 @@ class binary_eda_plot:
         
         ax2.plot(results['target_rate'], marker='o', color='red', label='target_rate')
 
-        ax2.plot(results['attr_rate'], marker='o', color='#00FF00', label='attr_rate')
+        # ax2.plot(results['attr_rate'], marker='o', color='#00FF00', label='attr_rate')
         
         ax2.set_yticklabels(['{:.0%}'.format(x) for x in ax2.get_yticks()])
         
